summaryrefslogtreecommitdiff
path: root/lib/chef/provider/script.rb
diff options
context:
space:
mode:
Diffstat (limited to 'lib/chef/provider/script.rb')
-rw-r--r--lib/chef/provider/script.rb4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/chef/provider/script.rb b/lib/chef/provider/script.rb
index c5966370f7..444eac54ac 100644
--- a/lib/chef/provider/script.rb
+++ b/lib/chef/provider/script.rb
@@ -49,9 +49,9 @@ class Chef
def load_current_resource
super
# @todo Chef-13: change this to an exception
if code.nil?
- logger.warn "#{new_resource}: No code attribute was given, resource does nothing, this behavior is deprecated and will be removed in Chef-13"
+ logger.warn "#{new_resource}: No code attribute was given, resource does nothing, this behavior is deprecated and will be removed in Chef 15 (April 2019)"
end
end
@@ -49,9 +49,9 @@ class Chef
def load_current_resource
super
- # @todo Chef-13: change this to an exception
+ # @todo Chef-15: change this to an exception
if code.nil?